==> server-api-impl-22.3.0-713.1815-sources.jar: com/xebialabs/deployit/core/rest/api/DeployServerResource.java <==
package com.xebialabs.deployit.core.rest.api;

import com.xebialabs.deployit.ServerConfiguration;
import com.xebialabs.deployit.booter.local.PluginVersions;
import com.xebialabs.deployit.core.providers.GeneralDataProvider;
import com.xebialabs.deployit.engine.api.dto.ServerInfo;
import com.xebialabs.deployit.engine.api.dto.ServerPluginInfo;
import com.xebialabs.deployit.engine.spi.exception.DeployitException;
import com.xebialabs.deployit.repository.RepositoryDatabaseMetaDataService;
import com.xebialabs.deployit.security.RoleService;
import com.xebialabs.deployit.security.authentication.viewas.ViewAsAuthenticationFinder;
import com.xebialabs.deployit.security.authentication.viewas.ViewAsData;
import com.xebialabs.license.service.LicenseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Controller;

import java.io.IOException;
import java.util.List;
import java.util.Properties;

@Controller
public class DeployServerResource extends ServerResource {

    private final RepositoryDatabaseMetaDataService databaseMetaDataService;

    private final ServerConfiguration deployServerConfiguration;

    private final GeneralDataProvider generalDataProvider;

    public DeployServerResource(@Autowired LicenseService licenseService,
                                @Autowired List<ViewAsAuthenticationFinder> viewAsAuthenticationFinders,
                                @Autowired RoleService roleService,
                                @Autowired ServerConfiguration serverConfiguration,
                                @Autowired ViewAsData viewAsData,
                                @Autowired RepositoryDatabaseMetaDataService databaseMetaDataService,
                                @Autowired GeneralDataProvider generalDataProvider) {
        super(licenseService, viewAsAuthenticationFinders, roleService, serverConfiguration, viewAsData);
        this.deployServerConfiguration = serverConfiguration;
        this.databaseMetaDataService = databaseMetaDataService;
        this.generalDataProvider = generalDataProvider;
    }

    @Override
    public ServerInfo getInfo() {
        ClassPathResource resource = new ClassPathResource("com/xebialabs/deployit/release.properties");
        Properties release = new Properties();
        try {
            release.load(resource.getInputStream());
            ServerInfo si = new ServerInfo();
            si.setVersion(release.getProperty("version"));
            si.setServerUrl(this.deployServerConfiguration.getServerUrl());

            for (String plugin : PluginVersions.getRegisteredPlugins()) {
                si.getPluginsInfo().add(new ServerPluginInfo(plugin, PluginVersions.getVersionFor(plugin)));
            }
            si.setClasspathEntries(getServerClassPath());
            si.setDatabaseInfo(databaseMetaDataService.findMainDbImplementation());
            si.setGeneralInfo(generalDataProvider.collectStatistics());
            return si;
        } catch (IOException e) {
            throw new DeployitException(e);
        }
    }
}

==> server-api-impl-24.3.11-915.1125-sources.jar: com/xebialabs/deployit/core/rest/api/DeployServerResource.java <==
package com.xebialabs.deployit.core.rest.api;

import com.xebialabs.deployit.ServerConfiguration;
import com.xebialabs.deployit.booter.local.PluginVersions;
import com.xebialabs.deployit.engine.api.dto.ServerInfo;
import com.xebialabs.deployit.engine.api.dto.ServerPluginInfo;
import com.xebialabs.deployit.engine.spi.exception.DeployitException;
import com.xebialabs.deployit.repository.RepositoryDatabaseMetaDataService;
import com.xebialabs.deployit.security.RoleService;
import com.xebialabs.deployit.security.authentication.viewas.ViewAsAuthenticationFinder;
import com.xebialabs.deployit.security.authentication.viewas.ViewAsData;
import com.xebialabs.license.service.LicenseService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Controller;

import java.io.IOException;
import java.util.List;
import java.util.Properties;

@Controller
public class DeployServerResource extends ServerResource {

    private final RepositoryDatabaseMetaDataService databaseMetaDataService;

    private final ServerConfiguration deployServerConfiguration;

    public DeployServerResource(@Autowired LicenseService licenseService,
                                @Autowired List<ViewAsAuthenticationFinder> viewAsAuthenticationFinders,
                                @Autowired RoleService roleService,
                                @Autowired ServerConfiguration serverConfiguration,
                                @Autowired ViewAsData viewAsData,
                                @Autowired RepositoryDatabaseMetaDataService databaseMetaDataService) {
        super(licenseService, viewAsAuthenticationFinders, roleService, serverConfiguration, viewAsData);
        this.deployServerConfiguration = serverConfiguration;
        this.databaseMetaDataService = databaseMetaDataService;
    }

    @Override
    public ServerInfo getInfo() {
        ClassPathResource resource = new ClassPathResource("com/xebialabs/deployit/release.properties");
        Properties release = new Properties();
        try {
            release.load(resource.getInputStream());
            ServerInfo si = new ServerInfo();
            si.setVersion(release.getProperty("version"));
            si.setServerUrl(this.deployServerConfiguration.getServerUrl());

            for (String plugin : PluginVersions.getRegisteredPlugins()) {
                si.getPluginsInfo().add(new ServerPluginInfo(plugin, PluginVersions.getVersionFor(plugin)));
            }
            si.setDatabaseInfo(databaseMetaDataService.findMainDbImplementation());
            return si;
        } catch (IOException e) {
            throw new DeployitException(e);
        }
    }
}
